@@ -269,7 +269,7 @@ KFS <-  function(model, filtering, smoothing, simplify = TRUE,
           simtmp$nNonzeroP1, as.integer(nsim), simtmp$epsplus,
           simtmp$etaplus, simtmp$aplus1, simtmp$c2, model$tol, info = integer(1),
           maxiter = as.integer(maxiter),
-          convtol = convtol, simtmp$zeroP1inf, length(simtmp$zeroP1inf),
+          convtol = convtol,
           a = array(0, ("state" %in% filtering) * c(m - 1, n - 1) + 1),
           P = array(0, ("state" %in% filtering) * c(m - 1, m - 1, n - 1) + 1),
           theta = array(0, ("signal" %in% filtering) * c(p - 1, n - 1) + 1),
@@ -318,7 +318,6 @@ KFS <-  function(model, filtering, smoothing, simplify = TRUE,
             as.integer(nsim), simtmp$epsplus, simtmp$etaplus, simtmp$aplus1, simtmp$c2,
             model$tol, info = integer(1),
             maxiter = as.integer(maxiter),  convtol = convtol,
-            simtmp$zeroP1inf, length(simtmp$zeroP1inf),
             alphahat = array(0, ("state" %in% smoothing) * c(m - 1, n - 1) + 1),
             V = array(0, ("state" %in% smoothing) * c(m - 1, m - 1, n - 1) + 1),
             thetahat = array(0, ("signal" %in% smoothing) * c(p - 1, n - 1) + 1),
@@ -327,7 +326,7 @@ KFS <-  function(model, filtering, smoothing, simplify = TRUE,
             V_mu = array(0, ("mean" %in% smoothing) * c(p - 1, p - 1, n - 1) + 1),
             as.integer("state" %in%  smoothing), as.integer("signal" %in% smoothing),
             as.integer("mean" %in% smoothing))
-        if(smoothout$info!=0){
+        if (smoothout$info != 0) {
           switch(as.character(smoothout$info),
             "-3" = stop("Couldn't compute LDL decomposition of P1."),
             "-2" =  stop("Couldn't compute LDL decomposition of Q."),
