@@ -1,4 +1,4 @@
-context("Miscellancelous")
+context("miscellaneous")
 
 test_that("hatvalues works properly",{
 model <- SSModel(sr ~ pop15 + pop75 + dpi + ddpi, data = LifeCycleSavings)
@@ -6,7 +6,7 @@ out <- KFS(model, filtering = "state", smoothing = "none")
 # estimate sigma2
 model["H"] <- mean(c(out$v[1:out$d][out$Finf==0]^2/out$F[1:out$d][out$Finf==0],
                       out$v[-(1:out$d)]^2/out$F[-(1:out$d)]))
-expect_equal(c(hatvalues(KFS(model))), 
+expect_equal(c(hatvalues(KFS(model))),
              hatvalues(lm(sr ~ pop15 + pop75 + dpi + ddpi, data = LifeCycleSavings)),
              check.attributes = FALSE, tol=1e-6)
 })
